==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/scheduler/kotlin/inputs/ServiceBusQueueMessageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scheduler.kotlin.inputs

import com.pulumi.azurenative.scheduler.inputs.ServiceBusQueueMessageArgs.builder
import com.pulumi.azurenative.scheduler.kotlin.enums.ServiceBusTransportType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property authentication Gets or sets the Service Bus authentication.
 * @property brokeredMessageProperties Gets or sets the brokered message properties.
 * @property customMessageProperties Gets or sets the custom message properties.
 * @property message Gets or sets the message.
 * @property namespace Gets or sets the namespace.
 * @property queueName Gets or sets the queue name.
 * @property transportType Gets or sets the transport type.
 */
public data class ServiceBusQueueMessageArgs(
    public val authentication: Output<ServiceBusAuthenticationArgs>? = null,
    public val brokeredMessageProperties: Output<ServiceBusBrokeredMessagePropertiesArgs>? = null,
    public val customMessageProperties: Output<Map<String, String>>? = null,
    public val message: Output<String>? = null,
    public val namespace: Output<String>? = null,
    public val queueName: Output<String>? = null,
    public val transportType: Output<ServiceBusTransportType>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scheduler.inputs.ServiceBusQueueMessageArgs> {
    override fun toJava(): com.pulumi.azurenative.scheduler.inputs.ServiceBusQueueMessageArgs =
        com.pulumi.azurenative.scheduler.inputs.ServiceBusQueueMessageArgs.builder()
            .authentication(authentication?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .brokeredMessageProperties(
                brokeredMessageProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customMessageProperties(
                customMessageProperties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .message(message?.applyValue({ args0 -> args0 }))
            .namespace(namespace?.applyValue({ args0 -> args0 }))
            .queueName(queueName?.applyValue({ args0 -> args0 }))
            .transportType(transportType?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ServiceBusQueueMessageArgs].
 */
@PulumiTagMarker
public class ServiceBusQueueMessageArgsBuilder internal constructor() {
    private var authentication: Output<ServiceBusAuthenticationArgs>? = null

    private var brokeredMessageProperties: Output<ServiceBusBrokeredMessagePropertiesArgs>? = null

    private var customMessageProperties: Output<Map<String, String>>? = null

    private var message: Output<String>? = null

    private var namespace: Output<String>? = null

    private var queueName: Output<String>? = null

    private var transportType: Output<ServiceBusTransportType>? = null

    /**
     * @param value Gets or sets the Service Bus authentication.
     */
    @JvmName("ytsmavajhldxueso")
    public suspend fun authentication(`value`: Output<ServiceBusAuthenticationArgs>) {
        this.authentication = value
    }

    /**
     * @param value Gets or sets the brokered message properties.
     */
    @JvmName("amybxtyeawnuhcbl")
    public suspend
    fun brokeredMessageProperties(`value`: Output<ServiceBusBrokeredMessagePropertiesArgs>) {
        this.brokeredMessageProperties = value
    }

    /**
     * @param value Gets or sets the custom message properties.
     */
    @JvmName("mamkvysibmajnoap")
    public suspend fun customMessageProperties(`value`: Output<Map<String, String>>) {
        this.customMessageProperties = value
    }

    /**
     * @param value Gets or sets the message.
     */
    @JvmName("kfgcrevqbutkherc")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value Gets or sets the namespace.
     */
    @JvmName("ggeqgupcwlsfjfvi")
    public suspend fun namespace(`value`: Output<String>) {
        this.namespace = value
    }

    /**
     * @param value Gets or sets the queue name.
     */
    @JvmName("qacmrtsftwwdepsh")
    public suspend fun queueName(`value`: Output<String>) {
        this.queueName = value
    }

    /**
     * @param value Gets or sets the transport type.
     */
    @JvmName("kfffhkinycfwnukg")
    public suspend fun transportType(`value`: Output<ServiceBusTransportType>) {
        this.transportType = value
    }

    /**
     * @param value Gets or sets the Service Bus authentication.
     */
    @JvmName("xpxmrxhksbbayabf")
    public suspend fun authentication(`value`: ServiceBusAuthenticationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param argument Gets or sets the Service Bus authentication.
     */
    @JvmName("qbxugfficknygckn")
    public suspend
    fun authentication(argument: suspend ServiceBusAuthenticationArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusAuthenticationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.authentication = mapped
    }

    /**
     * @param value Gets or sets the brokered message properties.
     */
    @JvmName("kjvtjkkfnbihwvoh")
    public suspend fun brokeredMessageProperties(`value`: ServiceBusBrokeredMessagePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.brokeredMessageProperties = mapped
    }

    /**
     * @param argument Gets or sets the brokered message properties.
     */
    @JvmName("jhiaukjvgwqclxtf")
    public suspend
    fun brokeredMessageProperties(argument: suspend ServiceBusBrokeredMessagePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusBrokeredMessagePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.brokeredMessageProperties = mapped
    }

    /**
     * @param value Gets or sets the custom message properties.
     */
    @JvmName("tfuerxteuqvxfioq")
    public suspend fun customMessageProperties(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customMessageProperties = mapped
    }

    /**
     * @param values Gets or sets the custom message properties.
     */
    @JvmName("ucafccwclflsyrum")
    public fun customMessageProperties(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customMessageProperties = mapped
    }

    /**
     * @param value Gets or sets the message.
     */
    @JvmName("btiyeufpmevxfmpo")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value Gets or sets the namespace.
     */
    @JvmName("ukhprhqahrgdmpgy")
    public suspend fun namespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespace = mapped
    }

    /**
     * @param value Gets or sets the queue name.
     */
    @JvmName("gwkyyxxlivfosjnm")
    public suspend fun queueName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queueName = mapped
    }

    /**
     * @param value Gets or sets the transport type.
     */
    @JvmName("ropyhapnvampnjkd")
    public suspend fun transportType(`value`: ServiceBusTransportType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transportType = mapped
    }

    internal fun build(): ServiceBusQueueMessageArgs = ServiceBusQueueMessageArgs(
        authentication = authentication,
        brokeredMessageProperties = brokeredMessageProperties,
        customMessageProperties = customMessageProperties,
        message = message,
        namespace = namespace,
        queueName = queueName,
        transportType = transportType,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/scheduler/kotlin/inputs/ServiceBusQueueMessageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scheduler.kotlin.inputs

import com.pulumi.azurenative.scheduler.inputs.ServiceBusQueueMessageArgs.builder
import com.pulumi.azurenative.scheduler.kotlin.enums.ServiceBusTransportType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property authentication Gets or sets the Service Bus authentication.
 * @property brokeredMessageProperties Gets or sets the brokered message properties.
 * @property customMessageProperties Gets or sets the custom message properties.
 * @property message Gets or sets the message.
 * @property namespace Gets or sets the namespace.
 * @property queueName Gets or sets the queue name.
 * @property transportType Gets or sets the transport type.
 */
public data class ServiceBusQueueMessageArgs(
    public val authentication: Output<ServiceBusAuthenticationArgs>? = null,
    public val brokeredMessageProperties: Output<ServiceBusBrokeredMessagePropertiesArgs>? = null,
    public val customMessageProperties: Output<Map<String, String>>? = null,
    public val message: Output<String>? = null,
    public val namespace: Output<String>? = null,
    public val queueName: Output<String>? = null,
    public val transportType: Output<ServiceBusTransportType>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scheduler.inputs.ServiceBusQueueMessageArgs> {
    override fun toJava(): com.pulumi.azurenative.scheduler.inputs.ServiceBusQueueMessageArgs =
        com.pulumi.azurenative.scheduler.inputs.ServiceBusQueueMessageArgs.builder()
            .authentication(authentication?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .brokeredMessageProperties(
                brokeredMessageProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customMessageProperties(
                customMessageProperties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .message(message?.applyValue({ args0 -> args0 }))
            .namespace(namespace?.applyValue({ args0 -> args0 }))
            .queueName(queueName?.applyValue({ args0 -> args0 }))
            .transportType(transportType?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ServiceBusQueueMessageArgs].
 */
@PulumiTagMarker
public class ServiceBusQueueMessageArgsBuilder internal constructor() {
    private var authentication: Output<ServiceBusAuthenticationArgs>? = null

    private var brokeredMessageProperties: Output<ServiceBusBrokeredMessagePropertiesArgs>? = null

    private var customMessageProperties: Output<Map<String, String>>? = null

    private var message: Output<String>? = null

    private var namespace: Output<String>? = null

    private var queueName: Output<String>? = null

    private var transportType: Output<ServiceBusTransportType>? = null

    /**
     * @param value Gets or sets the Service Bus authentication.
     */
    @JvmName("sanbgfbsspdyhons")
    public suspend fun authentication(`value`: Output<ServiceBusAuthenticationArgs>) {
        this.authentication = value
    }

    /**
     * @param value Gets or sets the brokered message properties.
     */
    @JvmName("rqmwtcavsbowymgc")
    public suspend
    fun brokeredMessageProperties(`value`: Output<ServiceBusBrokeredMessagePropertiesArgs>) {
        this.brokeredMessageProperties = value
    }

    /**
     * @param value Gets or sets the custom message properties.
     */
    @JvmName("gyetlbjxnqcwuypy")
    public suspend fun customMessageProperties(`value`: Output<Map<String, String>>) {
        this.customMessageProperties = value
    }

    /**
     * @param value Gets or sets the message.
     */
    @JvmName("wewsfluelfldlyos")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value Gets or sets the namespace.
     */
    @JvmName("qlyurqsyexahkwsr")
    public suspend fun namespace(`value`: Output<String>) {
        this.namespace = value
    }

    /**
     * @param value Gets or sets the queue name.
     */
    @JvmName("caxpeakqyrgnjovx")
    public suspend fun queueName(`value`: Output<String>) {
        this.queueName = value
    }

    /**
     * @param value Gets or sets the transport type.
     */
    @JvmName("kfoavjcvsryvmbdx")
    public suspend fun transportType(`value`: Output<ServiceBusTransportType>) {
        this.transportType = value
    }

    /**
     * @param value Gets or sets the Service Bus authentication.
     */
    @JvmName("wdjvrogvsritxhht")
    public suspend fun authentication(`value`: ServiceBusAuthenticationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param argument Gets or sets the Service Bus authentication.
     */
    @JvmName("ooudnncjyrknteiq")
    public suspend
    fun authentication(argument: suspend ServiceBusAuthenticationArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusAuthenticationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.authentication = mapped
    }

    /**
     * @param value Gets or sets the brokered message properties.
     */
    @JvmName("sbiapbkvavlrnnbl")
    public suspend fun brokeredMessageProperties(`value`: ServiceBusBrokeredMessagePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.brokeredMessageProperties = mapped
    }

    /**
     * @param argument Gets or sets the brokered message properties.
     */
    @JvmName("feiakptqxddnfrlv")
    public suspend
    fun brokeredMessageProperties(argument: suspend ServiceBusBrokeredMessagePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusBrokeredMessagePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.brokeredMessageProperties = mapped
    }

    /**
     * @param value Gets or sets the custom message properties.
     */
    @JvmName("pvldsebifqvjxcha")
    public suspend fun customMessageProperties(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customMessageProperties = mapped
    }

    /**
     * @param values Gets or sets the custom message properties.
     */
    @JvmName("urnxpxrgieijorlq")
    public fun customMessageProperties(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customMessageProperties = mapped
    }

    /**
     * @param value Gets or sets the message.
     */
    @JvmName("ewalwbhgjgsiybhs")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value Gets or sets the namespace.
     */
    @JvmName("gaakuquveiyqgtnu")
    public suspend fun namespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespace = mapped
    }

    /**
     * @param value Gets or sets the queue name.
     */
    @JvmName("vtrgoivvewcqckuj")
    public suspend fun queueName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queueName = mapped
    }

    /**
     * @param value Gets or sets the transport type.
     */
    @JvmName("iaevkukuomnumpmf")
    public suspend fun transportType(`value`: ServiceBusTransportType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transportType = mapped
    }

    internal fun build(): ServiceBusQueueMessageArgs = ServiceBusQueueMessageArgs(
        authentication = authentication,
        brokeredMessageProperties = brokeredMessageProperties,
        customMessageProperties = customMessageProperties,
        message = message,
        namespace = namespace,
        queueName = queueName,
        transportType = transportType,
    )
}
